@@ -21,3 +21,10 @@ def test_pq_outputs_with_provided_precision(capsys):
 def test_pq_outputs_scientific_notation(capsys):
     pq(Q_(1234000000.12345678, 'm/s^2'), scientific=True)
     assert capsys.readouterr().out == '1.23e+09 m/s^2^\n'
+
+
+def test_pq_handles_bare_number(capsys):
+    pq(1.42, precision=4)
+    assert capsys.readouterr().out == '1.4200\n'
+    pq(3.14e10, scientific=True)
+    assert capsys.readouterr().out == '3.14e+10\n'
