@@ -6,7 +6,10 @@ from .checks import *
 from .conversions import *
 
 ureg = UnitRegistry()
-ureg.setup_matplotlib()
+try:
+    ureg.setup_matplotlib()
+except ModuleNotFoundError:
+    pass
 set_application_registry(ureg)
 Q_ = ureg.Quantity
 
@@ -30,6 +33,11 @@ pint.formatting._KNOWN_TYPES = \
 # concise function for printing quantities (i.e. numbers with units) with
 # formatting for the units
 def pq(q, precision=3, scientific=False):
+    try:
+        q.units
+    except AttributeError:
+        q = Q_(q, '')
+
     if scientific:
         num_type = 'g'
     else:
